@@ -13,7 +13,9 @@ Usage (cli):
 Usage (module):
 
     import jc.parsers.csv_s
-    result = jc.parsers.csv_s.parse(csv_output)
+    result = jc.parsers.csv_s.parse(csv_output.splitlines())    # result is an iterable object
+    for item in result:
+        # do something
 
 Schema:
 
@@ -21,7 +23,13 @@ Schema:
 
     {
       "column_name1":     string,
-      "column_name2":     string
+      "column_name2":     string,
+      "_jc_meta":                    # This object only exists if using -qq or ignore_exceptions=True
+        {
+          "success":    booean,      # true if successfully parsed, false if error
+          "error":      string,      # exists if "success" is false
+          "line":       string       # exists if "success" is false
+        }
     }
 
 Examples:
@@ -48,7 +56,7 @@ from jc.exceptions import ParseError
 
 class info():
     """Provides parser metadata (version, author, etc.)"""
-    version = '1.0'
+    version = '1.1'
     description = 'CSV file streaming parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
@@ -95,8 +103,8 @@ def parse(data, raw=False, quiet=False, ignore_exceptions=False):
 
         Iterator object
     """
-    if not quiet:
-        jc.utils.compatibility(__name__, info.compatible)
+    jc.utils.compatibility(__name__, info.compatible, quiet)
+    jc.utils.streaming_input_type_check(data)
 
     # convert data to an iterable in case a sequence like a list is used as input.
     # this allows the exhaustion of the input so we don't double-process later.
