@@ -354,7 +354,7 @@ import jc.utils
 
 class info():
     """Provides parser metadata (version, author, etc.)"""
-    version = '1.11'
+    version = '1.12'
     description = '`netstat` command parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
@@ -424,8 +424,8 @@ def parse(data, raw=False, quiet=False):
         List of Dictionaries. Raw or processed structured data.
     """
     import jc.utils
-    if not quiet:
-        jc.utils.compatibility(__name__, info.compatible)
+    jc.utils.compatibility(__name__, info.compatible, quiet)
+    jc.utils.input_type_check(data)
 
     cleandata = list(filter(None, data.splitlines()))
     raw_output = []
