@@ -17,6 +17,12 @@ class MyTests(unittest.TestCase):
         with open(os.path.join(THIS_DIR, os.pardir, 'tests/fixtures/osx-10.14.6/airport-s.json'), 'r', encoding='utf-8') as f:
             self.osx_10_14_6_airport_s_json = json.loads(f.read())
 
+    def test_airport_s_nodata(self):
+        """
+        Test 'airport -s' with no data
+        """
+        self.assertEqual(jc.parsers.airport_s.parse('', quiet=True), [])
+
     def test_airport_s_osx_10_14_6(self):
         """
         Test 'airport -s' on OSX 10.14.6
