@@ -16,6 +16,9 @@ class MyTests(unittest.TestCase):
         with open(os.path.join(THIS_DIR, os.pardir, 'tests/fixtures/centos-7.7/crontab-u.out'), 'r', encoding='utf-8') as f:
             self.centos_7_7_crontab_u = f.read()
 
+        with open(os.path.join(THIS_DIR, os.pardir, 'tests/fixtures/debian10/crontab-u.out'), 'r', encoding='utf-8') as f:
+            self.debian10_crontab_u = f.read()
+
         # output
         with open(os.path.join(THIS_DIR, os.pardir, 'tests/fixtures/ubuntu-18.04/crontab-u.json'), 'r', encoding='utf-8') as f:
             self.ubuntu_18_4_crontab_u_json = json.loads(f.read())
@@ -23,6 +26,15 @@ class MyTests(unittest.TestCase):
         with open(os.path.join(THIS_DIR, os.pardir, 'tests/fixtures/centos-7.7/crontab-u.json'), 'r', encoding='utf-8') as f:
             self.centos_7_7_crontab_u_json = json.loads(f.read())
 
+        with open(os.path.join(THIS_DIR, os.pardir, 'tests/fixtures/debian10/crontab-u.json'), 'r', encoding='utf-8') as f:
+            self.debian10_crontab_u_json = json.loads(f.read())
+
+    def test_crontab_u_nodata(self):
+        """
+        Test 'crontab' with no data (has a user field)
+        """
+        self.assertEqual(jc.parsers.crontab_u.parse('', quiet=True), {})
+
     def test_crontab_u_ubuntu_18_4(self):
         """
         Test 'crontab' on Ubuntu 18.4 (has a user field)
@@ -35,6 +47,12 @@ class MyTests(unittest.TestCase):
         """
         self.assertEqual(jc.parsers.crontab_u.parse(self.centos_7_7_crontab_u, quiet=True), self.centos_7_7_crontab_u_json)
 
+    def test_crontab_u_debian10(self):
+        """
+        Test 'crontab' on Debian10 (has a user field)
+        """
+        self.assertEqual(jc.parsers.crontab_u.parse(self.debian10_crontab_u, quiet=True), self.debian10_crontab_u_json)
+
 
 if __name__ == '__main__':
     unittest.main()
